@@ -14,12 +14,12 @@ from functools import partial
 from pydev_ipython.version import check_version
 
 # Available APIs.
-QT_API_PYQT = 'pyqt'
-QT_API_PYQTv1 = 'pyqtv1'
-QT_API_PYQT_DEFAULT = 'pyqtdefault'  # don't set SIP explicitly
-QT_API_PYSIDE = 'pyside'
-QT_API_PYSIDE2 = 'pyside2'
-QT_API_PYQT5 = 'pyqt5'
+QT_API_PYQT = "pyqt"
+QT_API_PYQTv1 = "pyqtv1"
+QT_API_PYQT_DEFAULT = "pyqtdefault"  # don't set SIP explicitly
+QT_API_PYSIDE = "pyside"
+QT_API_PYSIDE2 = "pyside2"
+QT_API_PYQT5 = "pyqt5"
 
 
 class ImportDenier(object):
@@ -41,10 +41,13 @@ class ImportDenier(object):
             return self
 
     def load_module(self, fullname):
-        raise ImportError("""
+        raise ImportError(
+            """
     Importing %s disabled by IPython, which has
     already imported an Incompatible QT Binding: %s
-    """ % (fullname, loaded_api()))
+    """
+            % (fullname, loaded_api())
+        )
 
 
 ID = ImportDenier()
@@ -53,14 +56,14 @@ sys.meta_path.append(ID)
 
 def commit_api(api):
     """Commit to a particular API, and trigger ImportErrors on subsequent
-       dangerous imports"""
+    dangerous imports"""
 
     if api == QT_API_PYSIDE:
-        ID.forbid('PyQt4')
-        ID.forbid('PyQt5')
+        ID.forbid("PyQt4")
+        ID.forbid("PyQt5")
     else:
-        ID.forbid('PySide')
-        ID.forbid('PySide2')
+        ID.forbid("PySide")
+        ID.forbid("PySide2")
 
 
 def loaded_api():
@@ -73,58 +76,60 @@ def loaded_api():
     -------
     None, 'pyside', 'pyside2', 'pyqt', or 'pyqtv1'
     """
-    if 'PyQt4.QtCore' in sys.modules:
+    if "PyQt4.QtCore" in sys.modules:
         if qtapi_version() == 2:
             return QT_API_PYQT
         else:
             return QT_API_PYQTv1
-    elif 'PySide.QtCore' in sys.modules:
+    elif "PySide.QtCore" in sys.modules:
         return QT_API_PYSIDE
-    elif 'PySide2.QtCore' in sys.modules:
+    elif "PySide2.QtCore" in sys.modules:
         return QT_API_PYSIDE2
-    elif 'PyQt5.QtCore' in sys.modules:
+    elif "PyQt5.QtCore" in sys.modules:
         return QT_API_PYQT5
     return None
 
 
 def has_binding(api):
     """Safely check for PyQt4 or PySide, without importing
-       submodules
+    submodules
 
-       Parameters
-       ----------
-       api : str [ 'pyqtv1' | 'pyqt' | 'pyside' | 'pyqtdefault']
-            Which module to check for
+    Parameters
+    ----------
+    api : str [ 'pyqtv1' | 'pyqt' | 'pyside' | 'pyqtdefault']
+         Which module to check for
 
-       Returns
-       -------
-       True if the relevant module appears to be importable
+    Returns
+    -------
+    True if the relevant module appears to be importable
     """
     # we can't import an incomplete pyside and pyqt4
     # this will cause a crash in sip (#1431)
     # check for complete presence before importing
-    module_name = {QT_API_PYSIDE: 'PySide',
-                   QT_API_PYSIDE2: 'PySide2',
-                   QT_API_PYQT: 'PyQt4',
-                   QT_API_PYQTv1: 'PyQt4',
-                   QT_API_PYQT_DEFAULT: 'PyQt4',
-                   QT_API_PYQT5: 'PyQt5',
-                   }
+    module_name = {
+        QT_API_PYSIDE: "PySide",
+        QT_API_PYSIDE2: "PySide2",
+        QT_API_PYQT: "PyQt4",
+        QT_API_PYQTv1: "PyQt4",
+        QT_API_PYQT_DEFAULT: "PyQt4",
+        QT_API_PYQT5: "PyQt5",
+    }
     module_name = module_name[api]
 
     import importlib
+
     try:
         # importing top level PyQt4/PySide module is ok...
         mod = __import__(module_name)
         # ...importing submodules is not
 
-        for check in ('QtCore', 'QtGui', 'QtSvg'):
-            if importlib.util.find_spec('%s.%s' % (module_name, check)) is None:
+        for check in ("QtCore", "QtGui", "QtSvg"):
+            if importlib.util.find_spec("%s.%s" % (module_name, check)) is None:
                 return False
 
         # we can also safely check PySide version
         if api == QT_API_PYSIDE:
-            return check_version(mod.__version__, '1.0.3')
+            return check_version(mod.__version__, "1.0.3")
         else:
             return True
     except ImportError:
@@ -143,7 +148,7 @@ def qtapi_version():
     except ImportError:
         return
     try:
-        return sip.getapi('QString')
+        return sip.getapi("QString")
     except ValueError:
         return
 
@@ -178,21 +183,20 @@ def import_pyqt4(version=2):
     import sip
 
     if version is not None:
-        sip.setapi('QString', version)
-        sip.setapi('QVariant', version)
+        sip.setapi("QString", version)
+        sip.setapi("QVariant", version)
 
     from PyQt4 import QtGui, QtCore, QtSvg
 
-    if not check_version(QtCore.PYQT_VERSION_STR, '4.7'):
-        raise ImportError("IPython requires PyQt4 >= 4.7, found %s" %
-                          QtCore.PYQT_VERSION_STR)
+    if not check_version(QtCore.PYQT_VERSION_STR, "4.7"):
+        raise ImportError("IPython requires PyQt4 >= 4.7, found %s" % QtCore.PYQT_VERSION_STR)
 
     # Alias PyQt-specific functions for PySide compatibility.
     QtCore.Signal = QtCore.pyqtSignal
     QtCore.Slot = QtCore.pyqtSlot
 
     # query for the API version (in case version == None)
-    version = sip.getapi('QString')
+    version = sip.getapi("QString")
     api = QT_API_PYQTv1 if version == 1 else QT_API_PYQT
     return QtCore, QtGui, QtSvg, api
 
@@ -219,6 +223,7 @@ def import_pyside():
     ImportErrors raised within this function are non-recoverable
     """
     from PySide import QtGui, QtCore, QtSvg  # @UnresolvedImport
+
     return QtCore, QtGui, QtSvg, QT_API_PYSIDE
 
 
@@ -229,6 +234,7 @@ def import_pyside2():
     ImportErrors raised within this function are non-recoverable
     """
     from PySide2 import QtGui, QtCore, QtSvg  # @UnresolvedImport
+
     return QtCore, QtGui, QtSvg, QT_API_PYSIDE
 
 
@@ -258,21 +264,21 @@ def load_qt(api_options):
     bindings (either becaues they aren't installed, or because
     an incompatible library has already been installed)
     """
-    loaders = {QT_API_PYSIDE: import_pyside,
-               QT_API_PYSIDE2: import_pyside2,
-               QT_API_PYQT: import_pyqt4,
-               QT_API_PYQTv1: partial(import_pyqt4, version=1),
-               QT_API_PYQT_DEFAULT: partial(import_pyqt4, version=None),
-               QT_API_PYQT5: import_pyqt5,
-               }
+    loaders = {
+        QT_API_PYSIDE: import_pyside,
+        QT_API_PYSIDE2: import_pyside2,
+        QT_API_PYQT: import_pyqt4,
+        QT_API_PYQTv1: partial(import_pyqt4, version=1),
+        QT_API_PYQT_DEFAULT: partial(import_pyqt4, version=None),
+        QT_API_PYQT5: import_pyqt5,
+    }
 
     for api in api_options:
-
         if api not in loaders:
             raise RuntimeError(
-                "Invalid Qt API %r, valid values are: %r, %r, %r, %r, %r, %r" %
-                (api, QT_API_PYSIDE, QT_API_PYSIDE, QT_API_PYQT,
-                 QT_API_PYQTv1, QT_API_PYQT_DEFAULT, QT_API_PYQT5))
+                "Invalid Qt API %r, valid values are: %r, %r, %r, %r, %r, %r"
+                % (api, QT_API_PYSIDE, QT_API_PYSIDE, QT_API_PYQT, QT_API_PYQTv1, QT_API_PYQT_DEFAULT, QT_API_PYQT5)
+            )
 
         if not can_import(api):
             continue
@@ -283,7 +289,8 @@ def load_qt(api_options):
         commit_api(api)
         return result
     else:
-        raise ImportError("""
+        raise ImportError(
+            """
     Could not load requested Qt binding. Please ensure that
     PyQt4 >= 4.7 or PySide >= 1.0.3 is available,
     and only one is imported per session.
@@ -294,9 +301,13 @@ def load_qt(api_options):
     PySide >= 1.0.3 installed:       %s
     PySide2 installed:               %s
     Tried to load:                   %r
-    """ % (loaded_api(),
-           has_binding(QT_API_PYQT),
-           has_binding(QT_API_PYQT5),
-           has_binding(QT_API_PYSIDE),
-           has_binding(QT_API_PYSIDE2),
-           api_options))
+    """
+            % (
+                loaded_api(),
+                has_binding(QT_API_PYQT),
+                has_binding(QT_API_PYQT5),
+                has_binding(QT_API_PYSIDE),
+                has_binding(QT_API_PYSIDE2),
+                api_options,
+            )
+        )
